import pandas as pd
import numpy as np
from statistics import mean
import math

# Costing for Case 4

inlets = pd.read_csv('ModifiedData_bc1.csv', header=None)
inl = pd.DataFrame(inlets)

outlets = pd.read_csv('SimuOutputs_bc1.csv', header=None)
outl = pd.DataFrame(outlets)

stack = 1.75
Acs = 400

n = len(inl)
print(n)

# Size of equipment
# SOFC [kW]
s_sofc = max(inl.iloc[:,18])*1000
# GT [MW] (gas turbine + compresser + recuperator)
s_gt = 0
# ST [kW] (steam turbine + steam generation + pump)
s_st = 0
# blower for standalone [kW]
s_blower = max(outl.iloc[:,16])*1000
# HX1 (only for standalone) [m2]
s_hx1 = max(outl.iloc[:,9])
# HX syngas preheater [m2]
s_hxpreh = max(outl.iloc[:,10])
# coal flow [kg/hr]
s_coal = mean(inl.iloc[:,24])

# Cost estimation
# unit price
# SOFC [$/kW] year=2016
p_sofc = 1000
# GT [$/268 MW] year=2016  n=0.6 (gas turbine + compresser + recuperator) 
p_gt = 73000000
# ST [$/kW] year=2018  n=0.6  (steam turbine + steam generation + pump)
p_st = 340
# blower [$/30 kW] year=1970  n=0.55
p_blower = 5120
# HX [$/100 m2] year=1970  n=0.71
p_hx = 8000
# syngas upstream process [$/ 135118 kg coal/hr]  year=2018  n=0.6
p_up = 2706336000
# fixed operating cost (annual) [$/ 135118 kg coal/hr]  year=2018
p_foc = 116136648
# variable operating cost (annual) [$/ 135118 kg coal/hr]  year=2018
p_voc = 80992713
# fuel cost (annual) [$/ 135118 kg coal/hr]  year=2018
p_f = 85078513

# parameters
# lifetime of plant
lt = 30
# CEPCI
cepci2018 = 603.1
cepci2016 = 541.7
cepci1970 = 123
# inflation rate / cost of debt
r_i = 0.05
# time value of money / required return on equality
i_tvm = 0.1

# costs
c_sofc = p_sofc * s_sofc
c_gt = p_gt * (s_gt/268)**0.6 * (cepci2018/cepci2016)
c_st = p_st * s_st**0.6
c_blower = p_blower * (s_blower/30)**0.55 * (cepci2018/cepci1970)
c_hx1 = p_hx * (s_hx1/100)**0.71 * (cepci2018/cepci1970)
c_hxpreh = p_hx * (s_hxpreh/100)**0.71 * (cepci2018/cepci1970)
c_up = p_up * (s_coal/135118)**0.6 
c_foc = p_foc * (s_coal/135118)
c_voc = p_voc * (s_coal/135118)
c_f = p_f * (s_coal/135118)

# NPV calculation
# for lt=30, 2018 - 2047
x = 1   # year count
cn_sofc = 0   # cumulate number of sofc
cc_pv = 0   # cumulate present value

n_sofc = np.zeros(lt)
c_cap = np.zeros(lt)
c_op = np.zeros(lt)
c_an = np.zeros(lt)
c_pv = np.zeros(lt)

# number of sofc needed in this year
n_sofc[1] = max(math.ceil(52.1429*x/n),1)
cn_sofc = cn_sofc + n_sofc[1] 
# capital cost
c_cap[1] = c_sofc * n_sofc[1] + c_gt + c_st + c_blower + c_hx1 + c_hxpreh + c_up 
# operating cost
c_op[1] = c_foc + c_voc + c_f
# annual cost
c_an[1] = c_cap[1] + c_op[1]
# present value
c_pv[1] = c_an[1] * (1+r_i)**(x-1) / (1+i_tvm)**(x-1)
cc_pv = cc_pv + c_pv[1]
x = x + 1

while x < lt:
    # numbers of SOFC needed in this year
    n_sofc[x] = max(math.ceil(52.1429*x/n),0)-cn_sofc
    cn_sofc = cn_sofc + n_sofc[x]
    # capital cost
    c_cap[x] = c_sofc * n_sofc[x]
    # operating cost
    c_op[x] = c_foc + c_voc + c_f
    # annual cost
    c_an[x] = c_cap[x] + c_op[x]
    # present value
    c_pv[x] = c_an[x] * (1+r_i)**(x-1) / (1+i_tvm)**(x-1)
    cc_pv = cc_pv + c_pv[x]
    x = x + 1

# report
stackeff = mean(inl.iloc[:,21])
print('SOFC stack efficiency(LHV) = %s' % stackeff)
neteff = mean(pd.concat([outl.iloc[:,22]]))
print('Overall plant efficiency(LHV) = %s' % neteff)
print('First year capital cost ($ Million) = $%s' % (c_cap[1]/1000000))
print('Average annual SOFC replacement cost ($ Million) = $%s' % (mean(c_cap[2:])/1000000))
print('Annual material,operating and maintenance cost ($ Million) = $%s' % (mean(c_op)/1000000))
LCOE = cc_pv/(550*lt*365*24)
print('LCOE ($/MWh) = $%s' % LCOE)
co2 = mean(inl.iloc[:n,9])*mean(inl.iloc[:n,19])/550*3600
print('CO2 emission (kg/MWh) = %s' % co2)
CCA = (LCOE - 97.5)/(868.8-co2)*1000
print('Cost of CO2 avoided (CCA) ($/tCO2) = %s' % CCA)
