import pandas as pd
import numpy as np
import matplotlib.pyplot as plt
import os
import win32com.client as win32

# Case 2: Standalone + steam cycle

data = pd.read_csv('ModifiedData_bc2.csv', header=None)

df = pd.DataFrame(data)

M = np.zeros((df.shape[0],30))

coal_HV = 26.12

aspen = win32.Dispatch('Apwn.Document')
aspen.InitFromArchive2(os.path.abspath('Steambottoming_bc2.bkp'))    

for y in range(df.shape[0]):

    x = y 

    # s = df.iloc[x,:]
    ## Inputs
    # Coal flow rate [kg/hr]
    aspen.Tree.FindNode(r"\Data\Blocks\GASIFIER\Data\Streams\COAL\Input\TOTFLOW\NC").Value = df.iloc[x,24]
    # Temp from postcombustor [deg C]
    aspen.Tree.FindNode(r"\Data\Streams\GASFSOFC\Input\TEMP\MIXED").Value = df.iloc[x,4]
    # Total flow from postcombustor [kg/s]
    aspen.Tree.FindNode(r"\Data\Streams\GASFSOFC\Input\TOTFLOW\MIXED").Value = df.iloc[x,19]
    # Composition from postcombustor (N2 O2 CO2 CO H2O H2 CH4)
    aspen.Tree.FindNode(r"\Data\Streams\GASFSOFC\Input\FLOW\MIXED\N2").Value = df.iloc[x,7]
    aspen.Tree.FindNode(r"\Data\Streams\GASFSOFC\Input\FLOW\MIXED\O2").Value = df.iloc[x,8]
    aspen.Tree.FindNode(r"\Data\Streams\GASFSOFC\Input\FLOW\MIXED\CO2").Value = df.iloc[x,9]
    aspen.Tree.FindNode(r"\Data\Streams\GASFSOFC\Input\FLOW\MIXED\CO").Value = df.iloc[x,10]
    aspen.Tree.FindNode(r"\Data\Streams\GASFSOFC\Input\FLOW\MIXED\H2O").Value = df.iloc[x,11]
    aspen.Tree.FindNode(r"\Data\Streams\GASFSOFC\Input\FLOW\MIXED\H2").Value = df.iloc[x,12]
    aspen.Tree.FindNode(r"\Data\Streams\GASFSOFC\Input\FLOW\MIXED\CH4").Value = df.iloc[x,13]
    # Air flow (increasing) [kg/s]
    aspen.Tree.FindNode(r"\Data\Streams\AIR1\Input\TOTFLOW\MIXED").Value = df.iloc[x,22]
  
    ## Run Aspen
    aspen.Engine.Reinit()
    aspen.Engine.Run2()

    def print_elements(obj, Stored_Output, level=0):
        if hasattr(obj, 'Elements'):
            for o in obj.Elements:
                Stored_Output = str(Stored_Output + o.Value)
        else:
            print ('Ownage')
        return(Stored_Output)

    Stored_Output = ''
    Warnings_Errors = print_elements(aspen.Tree.FindNode(r'\Data\Results Summary\Run-Status\Output\PER_ERROR'), Stored_Output)

    try:
        Total_Warnings = len(Warnings_Errors.split('warnings:')[1].split('The')[0].split())
    except IndexError:
        Total_Warnings = 0
        
    try:
        Total_Errors = len(Warnings_Errors.split('errors:')[1].split('The')[0].split())
    except IndexError:
        Total_Errors = 0

    print("Week " + str(x+1))
    print("The Total Number of Warnings were: " + str(Total_Warnings))
    print("The Total Number of Errors were: " + str(Total_Errors))
    if Total_Errors or Total_Warnings:
        print(Warnings_Errors)


    ## Outputs
    # Net power of the balance-of-plant (except SOFC stack) [MW]
    M[x,0] = aspen.Tree.FindNode(r"\Data\Streams\TOTALW\Output\POWER_OUT").Value
    # Steam turbine power [MW]
    M[x,1] = aspen.Tree.FindNode(r"\Data\Streams\STW\Output\POWER_OUT").Value
    # Gas mass flow to SOFC [kg/hr]
    M[x,2] = aspen.Tree.FindNode(r"\Data\Streams\TOSOFCFF\Output\MASSFLMX\MIXED").Value
    # Composition to SOFC (H2O O2 N2 CO CO2 H2 CH4)
    M[x,3] = aspen.Tree.FindNode(r"\Data\Streams\TOSOFCFF\Output\MOLEFRAC\MIXED\H2O").Value
    M[x,4] = aspen.Tree.FindNode(r"\Data\Streams\TOSOFCFF\Output\MOLEFRAC\MIXED\O2").Value
    M[x,5] = aspen.Tree.FindNode(r"\Data\Streams\TOSOFCFF\Output\MOLEFRAC\MIXED\N2").Value
    M[x,6] = aspen.Tree.FindNode(r"\Data\Streams\TOSOFCFF\Output\MOLEFRAC\MIXED\CO").Value
    M[x,7] = aspen.Tree.FindNode(r"\Data\Streams\TOSOFCFF\Output\MOLEFRAC\MIXED\CO2").Value
    M[x,8] = aspen.Tree.FindNode(r"\Data\Streams\TOSOFCFF\Output\MOLEFRAC\MIXED\H2").Value
    M[x,9] = aspen.Tree.FindNode(r"\Data\Streams\TOSOFCFF\Output\MOLEFRAC\MIXED\CH4").Value
    # Steam flow [kg/hr]
    M[x,10] = aspen.Tree.FindNode(r"\Data\Streams\WATER2\Output\MASSFLMX\MIXED").Value
    # Heat exchange area of HX1 [sqm]
    M[x,11] = aspen.Tree.FindNode(r"\Data\Blocks\HX1\Output\HX_AREAC").Value
    # Heat exchange area of HXsteam [sqm]
    M[x,12] = aspen.Tree.FindNode(r"\Data\Blocks\HXSTEAM\Output\HX_AREAC").Value
    # Heat exchange area of HXpreh [sqm]
    M[x,13] = aspen.Tree.FindNode(r"\Data\Blocks\HXPREH\Output\HX_AREAC").Value
    # Temp around HX1 [deg C] (Hotin Hotout Coldin Coldout)
    M[x,14] = aspen.Tree.FindNode(r"\Data\Streams\GAS0\Output\TEMP_OUT\MIXED").Value
    M[x,15] = aspen.Tree.FindNode(r"\Data\Streams\GAS1\Output\TEMP_OUT\MIXED").Value
    M[x,16] = aspen.Tree.FindNode(r"\Data\Streams\AIR2\Output\TEMP_OUT\MIXED").Value
    M[x,17] = aspen.Tree.FindNode(r"\Data\Streams\AIR4\Output\TEMP_OUT\MIXED").Value
    # Temp of flue gas out [deg C]
    M[x,18] = aspen.Tree.FindNode(r"\Data\Streams\GAS3\Output\TEMP_OUT\MIXED").Value
    # Gas flow from postcombustor [kg/hr]
    M[x,19] = aspen.Tree.FindNode(r"\Data\Streams\GAS1\Output\MASSFLMX\MIXED").Value
    # pump load [MW]
    M[x,20] = aspen.Tree.FindNode(r"\Data\Streams\W3\Output\POWER_OUT").Value
    # blower load [MW]
    M[x,21] = aspen.Tree.FindNode(r"\Data\Streams\W2\Output\POWER_OUT").Value
    # Heating duty of HX1 [MW]
    M[x,22] = aspen.Tree.FindNode(r"\Data\Blocks\HX1\Output\HX_DUTY").Value
    # Heating duty of HXsteam [MW]
    M[x,23] = aspen.Tree.FindNode(r"\Data\Blocks\HXSTEAM\Output\HX_DUTY").Value
    # Heating duty of HXpreh [MW]
    M[x,24] = aspen.Tree.FindNode(r"\Data\Blocks\HXPREH\Output\HX_DUTY").Value   
    # Pinch point (Hotin - Coldout for HX1)
    M[x,25] = M[x,14] - M[x,17]
    # Net power [MW]
    M[x,26] = df.iloc[x,18] - M[x,0]
    # %error fuel flow
    M[x,27] = abs(df.iloc[x,23] - M[x,2])/df.iloc[x,23]*100
    # Net Efficiency
    M[x,28] = M[x,26]*3600/(df.iloc[x,24]*coal_HV)*100
    # ST efficiency
    M[x,29] = -M[x,1]/M[x,23]*100


# order of output matrix M
# (1)Net power of balance-of-the-plant  (2)ST power (3)gas flow to SOFC  (4)composition to SOFC: H2O
# (5)O2  (6)N2 (7)CO (8)CO2 (9)H2 (10)CH4 (11)Steam flow (12)Area of HX1  (13)Area of HXsteam  (14)Area of HXpreh (15)HX1 Temp Hotin  (16)Hotout  (17)Coldin  (18)Coldout 
# (19)Temp flue gas out (20)gas flow from postcombustor  (21)pump load  (22)blower load
# (23)HX1 heat duty  (24)HXsteam heat duty  (25)HXpreh heat duty  (26)pinch point  (27)net power  (28)%error fuel 

Op = pd.DataFrame(M)
Op.to_csv(path_or_buf='SimuOutputs_bc2.csv',sep=',',header=None,index=None)
