clc;
close all;
clear all;

stack = 1.130159;    % number of SOFC stack to achieve 550MW
Acs = 400;    % cross secitonal area of fuel cell [cm2]
HV_syngas = 7.0211;  % syngas LHV [kJ/g]
HV_coal = 26.12;     % coal LHV [MJ/kg]   27.26 HHV

load('Workspace_DS.mat')
SimModel=('SOFC_model_with_degradation');

load_system(SimModel);
sim(SimModel);

% Data record
% order: (1)time, (2)stack power, (3)voltage, (4)FU, (5)PC temp, (6)fuel flow, (7)Air flow, (8)PC N2, (9)O2,
% (10)CO2, (11)CO, (12)H2O, (13)H2, (14)CH4, (15)PC flow, (16)load, (17)Tavg, (18)Degrate
M = [StackPower_Deg_kW.time'; StackPower_Deg_kW.signals.values'; Voltage_Deg_V.signals.values'; FU_stack.signals.values';
    PC_Temp.signals.values'; FCFuel_flow_g_s.signals.values'; Airflow.signals.values'; PC_N2.signals.values';
    PC_O2.signals.values'; PC_CO2.signals.values'; PC_CO.signals.values'; PC_H2O.signals.values'; PC_H2.signals.values';
    PC_CH4.signals.values'; PC_air_flow.signals.values'; FCLoad_A.signals.values'; Tavg.signals.values'; Degrate.signals.values'];
fid = fopen('datarecord.csv','wt');
fprintf(fid, '%f, %f, %f, %f, %f, %f, %f, %f, %f, %f, %f, %f, %f, %f, %f, %f, %f, %f\n', M);

mm = [];
mm(:,1) = M(:,39);
for i = 1:1:floor(size(M,2)/210)
    mm(:,i+1) = M(:,210*(i-1)+211);
end

% (19)corrected stack power [MW]
mm(19,:) = mm(2,:).*stack;
% (20)corrected PC flow [kg/s]
mm(20,:) = mm(15,:).*stack.*1000;
% (21)current density [A/cm2]
mm(21,:) = mm(16,:)./Acs;
% (22)stack efficiency 
mm(22,:) = mm(2,:)./(mm(6,:).*mm(4,:).*HV_syngas)*100;       
% (23)corrected air flow [kg/s]
mm(23,:) = mm(7,:).*stack.*1000;
% (24)corrected fuel flow [kg/hr]
mm(24,:) = mm(6,:).*stack.*3600;
% (25)coal flow [kg/hr]
mm(25,:) = mm(24,:)./348631.*141000;


fid = fopen('ModifiedData.csv','wt');
fprintf(fid, '%f, %f, %f, %f, %f, %f, %f, %f, %f, %f, %f, %f, %f, %f, %f, %f, %f, %f, %f, %f, %f, %f, %f, %f, %f\n', mm);

