import pandas as pd
import numpy as np
import matplotlib   
import matplotlib.pyplot as plt
from matplotlib.ticker import (MultipleLocator, FormatStrFormatter,
                               AutoMinorLocator)

# Graphing for Case 1

inlets = pd.read_csv('ModifiedData_bc2.csv', header=None)
inl = pd.DataFrame(inlets)

outlets = pd.read_csv('SimuOutputs_bc2.csv', header=None)
outl = pd.DataFrame(outlets)

sofcprofile = pd.read_csv('datarecord_bc2.csv', header=None)
sofc = pd.DataFrame(sofcprofile)

stack = 1.130159
Acs = 400

matplotlib.rc('xtick', labelsize=14)     
matplotlib.rc('ytick', labelsize=14)
font = {'family' : 'Times New Roman',
        'size'   : 16}	
matplotlib.rc('font', **font)
plt.rcParams["font.family"] = "serif"
plt.rcParams["font.serif"] = ["Times New Roman"] + plt.rcParams["font.serif"]

# power 
fig, ax = plt.subplots()
ax.plot(list(range(1,inl.shape[0]+1)),inl.iloc[:,18], 'r-', label='Stack Power')
ax.plot(list(range(1,inl.shape[0]+1)),-outl.iloc[:,0], 'k--', label='Steam Cycle Power')
ax.plot(list(range(1,inl.shape[0]+1)),outl.iloc[:,26], 'k-', label='Net Power')
plt.xlabel('Week')
plt.ylabel('Power [MW]')
plt.xlim(1,20)
plt.ylim(300,600)
leg = ax.legend()
chartBox = ax.get_position()
ax.set_position([chartBox.x0*1.5, chartBox.y0*2.3, chartBox.width*0.9, chartBox.height*0.9])
ax.legend(loc='upper center', bbox_to_anchor=(0.5, -0.15), ncol=3)
plt.savefig('Power_bc2.tif',dpi=200)

# efficiency
fig, ax = plt.subplots()
ax.plot(list(range(1,inl.shape[0]+1)),inl.iloc[:,21], 'r-', label='Stack Efficiency')
ax.plot(list(range(1,inl.shape[0]+1)),outl.iloc[:,29], 'k--', label='Steam Turbine Efficiency')
ax.plot(list(range(1,inl.shape[0]+1)),outl.iloc[:,28], 'k-', label='Net Efficiency')
plt.xlabel('Week')
plt.ylabel('Efficiency [%]')
plt.xlim(1,20)
plt.ylim(20,80)
leg = ax.legend()
chartBox = ax.get_position()
ax.legend(loc='upper center', bbox_to_anchor=(0.5, -0.15), ncol=3)
plt.savefig('Effic_bc2.tif',dpi=200)

# power and efficiency
fig, ax1 = plt.subplots()
ax1.plot(list(range(1,inl.shape[0]+1)),inl.iloc[:,18], 'r-', label='Stack Power')
ax1.plot(list(range(1,inl.shape[0]+1)),-outl.iloc[:,0], 'k:', label='Steam Cycle Power')
ax1.plot(list(range(1,inl.shape[0]+1)),outl.iloc[:,26], 'k-', label='Net Power')
plt.xlabel('Week')
plt.ylabel('Power [MW]')
plt.xlim(1,20)
plt.ylim(300,600)

ax2 = ax1.twinx()
ax2.set_ylabel('Efficiency [%]')
ax2.plot(list(range(1,inl.shape[0]+1)),inl.iloc[:,21], 'r--', label='Stack Eff')
ax2.plot(list(range(1,inl.shape[0]+1)),outl.iloc[:,29], 'k-.', label='Steam Cycle Eff')
ax2.plot(list(range(1,inl.shape[0]+1)),outl.iloc[:,28], 'k--', label='Net Eff')
ax2.tick_params(axis='y')
plt.ylim(20,80)
leg = ax.legend()
leg = ax2.legend()
chartBox = ax2.get_position()
ax2.set_position([chartBox.x0*1.5, chartBox.y0*2.6, chartBox.width*0.85, chartBox.height*0.85])
ax1.legend(loc='upper center', bbox_to_anchor=(0.5, -0.15), ncol=3)
ax2.legend(loc='upper center', bbox_to_anchor=(0.5, -0.28), ncol=3)
plt.savefig('Overall_bc2.tif',dpi=200)

# periodically 

tm = list(range(1,inl.shape[0]*3+1))
stpr = pd.concat([inl.iloc[:,18], inl.iloc[:,18], inl.iloc[:,18]])
scpr = pd.concat([-outl.iloc[:,0], -outl.iloc[:,0], -outl.iloc[:,0]])
ntpr = pd.concat([outl.iloc[:,26], outl.iloc[:,26], outl.iloc[:,26]])
stef = pd.concat([inl.iloc[:,21], inl.iloc[:,21], inl.iloc[:,21]])
scef = pd.concat([outl.iloc[:,29], outl.iloc[:,29], outl.iloc[:,29]])
ntef = pd.concat([outl.iloc[:,28], outl.iloc[:,28], outl.iloc[:,28]])

fig, ax1 = plt.subplots()
ax1.plot(tm, stpr, 'r-', label='Stack Power')
ax1.plot(tm, scpr, 'k:', label='Steam Cycle Power')
ax1.plot(tm, ntpr, 'k-', label='Net Power')
plt.xlabel('Week')
plt.ylabel('Power [MW]')
plt.xlim(1,60)
plt.ylim(100,600)
plt.grid(b=None, which='major', axis='both', color='lightgrey')

ax2 = ax1.twinx()
ax2.set_ylabel('Efficiency [%]')
ax2.plot(tm, stef, 'r--', label='Stack Eff')
ax2.plot(tm, scef, 'k-.', label='Steam Cycle Eff')
ax2.plot(tm, ntef, 'k--', label='Net Eff')
ax2.tick_params(axis='y')
plt.ylim(20,80)
leg = ax.legend()
leg = ax2.legend()
chartBox = ax2.get_position()
ax2.set_position([chartBox.x0*1.5, chartBox.y0*2.6, chartBox.width*0.85, chartBox.height*0.85])
ax1.legend(loc='upper center', bbox_to_anchor=(0.5, -0.15), ncol=3)
ax2.legend(loc='upper center', bbox_to_anchor=(0.5, -0.28), ncol=3)
plt.savefig('2_Period_bc2.tif', dpi=200)

# SOFC profile
fig, ax1 = plt.subplots()
ax1.plot(range(20,sofc.shape[0]),sofc.iloc[20:,1]*stack, 'r-', label='Stack Power')
ax1.plot(range(20,sofc.shape[0]),sofc.iloc[20:,5]*stack, 'k-', label='Fuel Flow')
plt.xlabel('Time [h]')
plt.ylabel('Power [MW] / Fuel Flow [kg/s]')
plt.grid(b=None, which='major', axis='both', color='lightgrey')

ax2 = ax1.twinx()
ax2.set_ylabel(r'Voltage [V] / FU / Current Density [A/$\mathdefault{cm^2}$]')
ax2.plot(range(20,sofc.shape[0]),sofc.iloc[20:,2], 'r--', label='Voltage')
ax2.plot(range(20,sofc.shape[0]),sofc.iloc[20:,3], 'k--', label='FU')
ax2.plot(range(20,sofc.shape[0]),sofc.iloc[20:,15]/Acs, 'k-.', label='Current Density')
ax2.tick_params(axis='y')

leg = ax.legend()
leg = ax2.legend()
chartBox = ax2.get_position()
ax2.set_position([chartBox.x0*1.5, chartBox.y0*2.6, chartBox.width*0.85, chartBox.height*0.85])
ax1.legend(loc='upper center', bbox_to_anchor=(0.5, -0.15), ncol=2)
ax2.legend(loc='upper center', bbox_to_anchor=(0.5, -0.28), ncol=3)
plt.savefig('1_SOFCprofile_bc2.tif',dpi=200)

plt.show()

