import pandas as pd
import numpy as np
import matplotlib   
import matplotlib.pyplot as plt
from matplotlib.ticker import (MultipleLocator, FormatStrFormatter,
                               AutoMinorLocator)

# Graphing for Case 3

inlets = pd.read_csv('ModifiedData_bc3.csv', header=None)
inl = pd.DataFrame(inlets)

outlets1 = pd.read_csv('SimuOutputsPart1_bc3.csv', header=None)
outl1 = pd.DataFrame(outlets1)

outlets = pd.read_csv('SimuOutputs_bc3.csv', header=None)
outl = pd.DataFrame(outlets)

sofcprofile = pd.read_csv('datarecord_bc3.csv', header=None)
sofc = pd.DataFrame(sofcprofile)

stack = 1
Acs = 400
s = 10  #  # of cases in Part1
n = 0   #  lifetime of SOFC (FU=0.25)

while inl.iloc[n,3] > 0.25:
        n = n + 1

print(n)
print(inl.iloc[n,3])

matplotlib.rc('xtick', labelsize=14)     
matplotlib.rc('ytick', labelsize=14)
font = {'family' : 'Times New Roman',
        'size'   : 16}	
matplotlib.rc('font', **font)
plt.rcParams["font.family"] = "serif"
plt.rcParams["font.serif"] = ["Times New Roman"] + plt.rcParams["font.serif"]

# power 
gtpr = pd.concat([outl1.iloc[0:s,1], outl.iloc[s:n,1]])
ntpr = pd.concat([outl1.iloc[0:s,26], outl.iloc[s:n,26]])

fig, ax = plt.subplots()
ax.plot(list(range(1,n+1)),inl.iloc[:n,20], 'r-', label='Stack Power')
ax.plot(list(range(1,n+1)),-gtpr, 'k--', label='GT Power')
ax.plot(list(range(1,n+1)),ntpr, 'k-', label='Net Power')
plt.xlabel('Week')
plt.ylabel('Power [MW]')
plt.xlim(1,380)
leg = ax.legend()
chartBox = ax.get_position()
ax.set_position([chartBox.x0*1.5, chartBox.y0*2.3, chartBox.width*0.9, chartBox.height*0.9])
ax.legend(loc='upper center', bbox_to_anchor=(0.5, -0.15), ncol=3)
plt.savefig('Power_bc3.tif',dpi=200)

# efficiency
# gtef = outl.iloc[:,1]/(outl.iloc[:,0]/inl.iloc[:,19])*100
# ntef = outl.iloc[:,26]/(inl.iloc[:,25]/ 348631 * 141000 * 26.21/3600)*100
gtef = pd.concat([outl1.iloc[0:s,29], outl.iloc[s:n,29]])
ntef = pd.concat([outl1.iloc[0:s,30], outl.iloc[s:n,30]])

fig, ax = plt.subplots()
ax.plot(list(range(1,n+1)),inl.iloc[:n,23]*100, 'r-', label='Stack Eff')
ax.plot(list(range(1,n+1)),gtef, 'k--', label='GT Eff')
ax.plot(list(range(1,n+1)),ntef, 'k-', label='Net Eff')
plt.xlabel('Week')
plt.ylabel('Efficiency [%]')
plt.xlim(1,380)

leg = ax.legend()
chartBox = ax.get_position()
ax.legend(loc='upper center', bbox_to_anchor=(0.5, -0.15), ncol=3)
plt.savefig('Effic_bc3.tif',dpi=200)

# power and efficiency
fig, ax1 = plt.subplots()
ax1.plot(list(range(1,n+1)),inl.iloc[:n,20], 'r-', label='Stack Power')
ax1.plot(list(range(1,n+1)),-gtpr, 'r:', label='GT Power')
ax1.plot(list(range(1,n+1)),ntpr, 'k-', label='Net Power')
plt.xlabel('Week')
plt.ylabel('Power [MW]')
plt.xlim(1,380)
plt.grid(b=None, which='major', axis='both', color='lightgrey')


ax2 = ax1.twinx()
ax2.set_ylabel('Efficiency [%]')
ax2.plot(list(range(1,n+1)),inl.iloc[:n,23]*100, 'r--', label='Stack Eff')
ax2.plot(list(range(1,n+1)),gtef, 'r-.', label='GT Eff')
ax2.plot(list(range(1,n+1)),ntef, 'k--', label='Net Eff')
ax2.tick_params(axis='y')

leg = ax.legend()
leg = ax2.legend()
chartBox = ax2.get_position()
ax2.set_position([chartBox.x0*1.5, chartBox.y0*2.6, chartBox.width*0.85, chartBox.height*0.85])
ax1.legend(loc='upper center', bbox_to_anchor=(0.5, -0.15), ncol=3)
ax2.legend(loc='upper center', bbox_to_anchor=(0.5, -0.28), ncol=3)
plt.savefig('2_Overall_bc3.tif',dpi=200)


# SOFC profile
fig, ax1 = plt.subplots()
ax1.plot(range(20,sofc.shape[0]),sofc.iloc[20:,1]*stack, 'r-', label='Stack Power')
ax1.plot(range(20,sofc.shape[0]),sofc.iloc[20:,5]*stack, 'k-', label='Fuel Flow')
plt.xlabel('Time [h]')
plt.ylabel('Power [MW] / Fuel Flow [kg/s]')
plt.grid(b=None, which='major', axis='both', color='lightgrey')

ax2 = ax1.twinx()
ax2.set_ylabel('Voltage [V] / FU / Current Density [A/$\mathdefault{cm^2}$]')
ax2.plot(range(20,sofc.shape[0]),sofc.iloc[20:,2], 'r--', label='Voltage')
ax2.plot(range(20,sofc.shape[0]),sofc.iloc[20:,3], 'k--', label='FU')
ax2.plot(range(20,sofc.shape[0]),sofc.iloc[20:,15]/Acs, 'k-.', label='Current Density')
ax2.tick_params(axis='y')

leg = ax.legend()
leg = ax2.legend()
chartBox = ax2.get_position()
ax2.set_position([chartBox.x0*1.5, chartBox.y0*2.6, chartBox.width*0.85, chartBox.height*0.85])
ax1.legend(loc='upper center', bbox_to_anchor=(0.5, -0.15), ncol=2)
ax2.legend(loc='upper center', bbox_to_anchor=(0.5, -0.28), ncol=3)
plt.savefig('1_SOFCprofile_bc3.tif',dpi=200)

plt.show()

