clc;
close all;
clear all;

stack = 1;    % number of SOFC stack to achieve 550MW
Acs = 400;    % cross secitonal area of fuel cell [cm2]
HV_syngas = 7.0211;  % syngas LHV [kJ/g]
HV_coal = 26.12;     % coal LHV [MJ/kg]   27.26 HHV

load('Workspace_DS.mat')
SimModel=('HYBRID_with_degradation_AirTCont_FUmod_newGT_RampTin_bc4');

load_system(SimModel);
sim(SimModel);

% Data record
% order: (1)time, (2)stack power, (3)voltage, (4)FU, (5)PC temp, (6)fuel flow, (7)Air temp, (8)PC N2, (9)O2,
% (10)CO2, (11)CO, (12)H2O, (13)H2, (14)CH4, (15)PC flow, (16)load, (17)Tavg, (18)Degrate, (19)Turbine power,
% (20)Turbine Efficiency
M = [StackPower_Deg_kW.time'; StackPower_Deg_kW.signals.values'; Voltage_Deg_V.signals.values'; FUstack.signals.values';
    PC_temp.signals.values'; FCFuel_flow_g_s.signals.values'; AirTempin.signals.values'; PC_N2.signals.values';
    PC_O2.signals.values'; PC_CO2.signals.values'; PC_CO.signals.values'; PC_H2O.signals.values'; PC_H2.signals.values';
    PC_CH4.signals.values'; PC_flow.signals.values'; FCLoad_A.signals.values'; Tavg.signals.values'; Degrate.signals.values';
    TurbinePower.signals.values'; Turbine_Eff.signals.values'];
fid = fopen('datarecord_bc4.csv','wt');
fprintf(fid, '%f, %f, %f, %f, %f, %f, %f, %f, %f, %f, %f, %f, %f, %f, %f, %f, %f, %f, %f, %f\n', M);

mm = [];
mm(:,1) = M(:,61);
for i = 1:1:782
    mm(:,i+1) = M(:,210*(i-1)+211);
end

% (21)corrected stack power [MW]
mm(21,:) = mm(2,:).*stack;
% (22)corrected PC flow [kg/s]
mm(22,:) = mm(15,:).*stack;
% (23)current density [A/cm2]
mm(23,:) = mm(16,:)./Acs;
% (24)stack efficiency 
mm(24,:) = mm(2,:)./(mm(6,:).*mm(4,:).*HV_syngas);       
% (25)net power [MW]
mm(25,:) = mm(21,:) + mm(19,:);
% (26)corrected fuel flow [kg/hr]
mm(26,:) = mm(6,:).*stack.*3600;
% (27)coal flow [kg/hr]
mm(27,:) = mm(26,:)./348631.*141000;

fid = fopen('ModifiedData_bc4.csv','wt');
fprintf(fid, '%f, %f, %f, %f, %f, %f, %f, %f, %f, %f, %f, %f, %f, %f, %f, %f, %f, %f, %f, %f, %f, %f, %f, %f, %f, %f, %f\n', mm);

