import pandas as pd
import numpy as np
import matplotlib.pyplot as plt
import os
import win32com.client as win32

data = pd.read_csv('ModifiedData_bc4.csv', header=None)

df = pd.DataFrame(data)

M = np.zeros((783,38))

aspen = win32.Dispatch('Apwn.Document')
aspen.InitFromArchive2(os.path.abspath('Hybrid_bc4.bkp'))    
#aspen.visible = 1

n = 0   #  lifetime of SOFC (FU=0.25)

while df.iloc[n,3] > 0.25:
        n = n + 1

for y in range(n-19):

    x = y + 19

    # s = df.iloc[x,:]
    ## Inputs
    # Coal flow rate [kg/hr]
    aspen.Tree.FindNode(r"\Data\Blocks\GASIFIER\Data\Streams\COAL\Input\TOTFLOW\NC").Value = df.iloc[x,26]
    # Temp from postcombustor [deg C]
    aspen.Tree.FindNode(r"\Data\Streams\GASFSOFC\Input\TEMP\MIXED").Value = df.iloc[x,4]
    # Total flow from postcombustor [kg/s]
    aspen.Tree.FindNode(r"\Data\Streams\GASFSOFC\Input\TOTFLOW\MIXED").Value = df.iloc[x,21]
    # Composition from postcombustor (N2 O2 CO2 CO H2O H2 CH4)
    aspen.Tree.FindNode(r"\Data\Streams\GASFSOFC\Input\FLOW\MIXED\N2").Value = df.iloc[x,7]
    aspen.Tree.FindNode(r"\Data\Streams\GASFSOFC\Input\FLOW\MIXED\O2").Value = df.iloc[x,8]
    aspen.Tree.FindNode(r"\Data\Streams\GASFSOFC\Input\FLOW\MIXED\CO2").Value = df.iloc[x,9]
    aspen.Tree.FindNode(r"\Data\Streams\GASFSOFC\Input\FLOW\MIXED\CO").Value = df.iloc[x,10]
    aspen.Tree.FindNode(r"\Data\Streams\GASFSOFC\Input\FLOW\MIXED\H2O").Value = df.iloc[x,11]
    aspen.Tree.FindNode(r"\Data\Streams\GASFSOFC\Input\FLOW\MIXED\H2").Value = df.iloc[x,12]
    aspen.Tree.FindNode(r"\Data\Streams\GASFSOFC\Input\FLOW\MIXED\CH4").Value = df.iloc[x,13]
    # Temp_out from HX1 to anode [deg C]
    aspen.Tree.FindNode(r"\Data\Blocks\HX1\Input\VALUE").Value = df.iloc[x,6]
    # Isentropic efficiency of the gas turbine
    aspen.Tree.FindNode(r"\Data\Blocks\GASTURB\Input\SEFF").Value = 0.202157 + 4.89e-7*df.iloc[x,4]*df.iloc[x,21]
    # Power load for the balance-of-plant (except SOFC stack) in DS1 [MW]
    #aspen.Tree.FindNode(r"\Data\Flowsheeting Options\Design-Spec\DS-1\Input\EXPR2").Value = - (550 - (550 - df.iloc[x,18]))
    ## Run Aspen
    aspen.Engine.Reinit()
    aspen.Engine.Run2()

    def print_elements(obj, Stored_Output, level=0):
        if hasattr(obj, 'Elements'):
            for o in obj.Elements:
                Stored_Output = str(Stored_Output + o.Value)
        else:
            print ('Ownage')
        return(Stored_Output)

    Stored_Output = ''
    Warnings_Errors = print_elements(aspen.Tree.FindNode(r'\Data\Results Summary\Run-Status\Output\PER_ERROR'), Stored_Output)

    try:
        Total_Warnings = len(Warnings_Errors.split('warnings:')[1].split('The')[0].split())
    except IndexError:
        Total_Warnings = 0
        
    try:
        Total_Errors = len(Warnings_Errors.split('errors:')[1].split('The')[0].split())
    except IndexError:
        Total_Errors = 0

    print("Week " + str(x+1))
    print("The Total Number of Warnings were: " + str(Total_Warnings))
    print("The Total Number of Errors were: " + str(Total_Errors))
    if Total_Errors or Total_Warnings:
        print(Warnings_Errors)


    ## Outputs
    # Net power of the balance-of-plant (except SOFC stack) [MW]
    M[x,0] = aspen.Tree.FindNode(r"\Data\Streams\TOTALW\Output\POWER_OUT").Value
    # Net power of GT/compressor [MW]
    M[x,1] = aspen.Tree.FindNode(r"\Data\Streams\NW\Output\POWER_OUT").Value
    # GT gross power [MW]
    M[x,2] = aspen.Tree.FindNode(r"\Data\Blocks\GASTURB\Output\WNET").Value
    # Gas mass flow to SOFC [kg/hr]
    M[x,3] = aspen.Tree.FindNode(r"\Data\Streams\TOSOFCFF\Output\MASSFLMX\MIXED").Value
    # Composition to SOFC (H2O O2 N2 CO CO2 H2 CH4)
    M[x,4] = aspen.Tree.FindNode(r"\Data\Streams\TOSOFCFF\Output\MOLEFRAC\MIXED\H2O").Value
    M[x,5] = aspen.Tree.FindNode(r"\Data\Streams\TOSOFCFF\Output\MOLEFRAC\MIXED\O2").Value
    M[x,6] = aspen.Tree.FindNode(r"\Data\Streams\TOSOFCFF\Output\MOLEFRAC\MIXED\N2").Value
    M[x,7] = aspen.Tree.FindNode(r"\Data\Streams\TOSOFCFF\Output\MOLEFRAC\MIXED\CO").Value
    M[x,8] = aspen.Tree.FindNode(r"\Data\Streams\TOSOFCFF\Output\MOLEFRAC\MIXED\CO2").Value
    M[x,9] = aspen.Tree.FindNode(r"\Data\Streams\TOSOFCFF\Output\MOLEFRAC\MIXED\H2").Value
    M[x,10] = aspen.Tree.FindNode(r"\Data\Streams\TOSOFCFF\Output\MOLEFRAC\MIXED\CH4").Value
    # Heat exchange area of HX1 [sqm]
    M[x,11] = aspen.Tree.FindNode(r"\Data\Blocks\HX1\Output\HX_AREAC").Value
    # Heat exchange area of HXpreh [sqm]
    M[x,12] = aspen.Tree.FindNode(r"\Data\Blocks\HXPREH\Output\HX_AREAC").Value
    # Temp around HX1 [deg C] (Hotin Hotout Coldin Coldout)
    M[x,13] = aspen.Tree.FindNode(r"\Data\Streams\GAS2\Output\TEMP_OUT\MIXED").Value
    M[x,14] = aspen.Tree.FindNode(r"\Data\Streams\GAS3\Output\TEMP_OUT\MIXED").Value
    M[x,15] = aspen.Tree.FindNode(r"\Data\Streams\AIR3\Output\TEMP_OUT\MIXED").Value
    M[x,16] = aspen.Tree.FindNode(r"\Data\Streams\AIR4\Output\TEMP_OUT\MIXED").Value
    # Total Mass flow air [kg/hr]
    M[x,17] = aspen.Tree.FindNode(r"\Data\Streams\AIR1\Output\MASSFLMX\MIXED").Value
    # Mass flow bypass air [kg/hr]
    M[x,18] = aspen.Tree.FindNode(r"\Data\Streams\AIR3B\Output\MASSFLMX\MIXED").Value
    # Gas flow from postcombustor [kg/hr]
    M[x,19] = aspen.Tree.FindNode(r"\Data\Streams\GAS1\Output\MASSFLMX\MIXED").Value
    # Temp to GT before mixing [deg C]
    M[x,20] = aspen.Tree.FindNode(r"\Data\Streams\GAS1\Output\TEMP_OUT\MIXED").Value
    # Temp to GT after mixing [deg C]
    M[x,21] = aspen.Tree.FindNode(r"\Data\Streams\GAS1B\Output\TEMP_OUT\MIXED").Value
    # Heating duty of HX1 [MW]
    M[x,22] = aspen.Tree.FindNode(r"\Data\Blocks\HX1\Output\HX_DUTY").Value
    # Heating duty of HXpreh [MW]
    M[x,23] = aspen.Tree.FindNode(r"\Data\Blocks\HXPREH\Output\HX_DUTY").Value
    # GT output isentropic efficiency
    M[x,24] = aspen.Tree.FindNode(r"\Data\Blocks\GASTURB\Output\EPC").Value
    
    # Pinch point (Hotin - Coldout for HX1)
    M[x,25] = M[x,13] - M[x,16]

    # Steam flow rate [kg/hr]
    M[x,26] = aspen.Tree.FindNode(r"\Data\Streams\WATER1\Output\MASSFLMX\MIXED").Value
    # ST power (including pump) [MW]
    M[x,27] = aspen.Tree.FindNode(r"\Data\Streams\WST3\Output\POWER_OUT").Value
    # pump load [MW]
    M[x,28] = aspen.Tree.FindNode(r"\Data\Blocks\P1\Output\WNET").Value
    # Temp out flue gas [deg C]
    M[x,29] = aspen.Tree.FindNode(r"\Data\Streams\GAS4\Output\TEMP_OUT\MIXED").Value
    # Heating duty of HXsteam [MW]
    M[x,30] = aspen.Tree.FindNode(r"\Data\Blocks\HXST\Output\HX_DUTY").Value
    # Heat exchange area of HXsteam [sqm]
    M[x,31] = aspen.Tree.FindNode(r"\Data\Blocks\HXST\Output\HX_AREAC").Value
    # Cooling duty of the condenser [MW]
    M[x,32] = aspen.Tree.FindNode(r"\Data\Blocks\COND\Output\QNET").Value
    # Net power [MW]
    M[x,33] = df.iloc[x,1] - M[x,0]
    # %error fuel flow
    M[x,34] = abs(df.iloc[x,5] - M[x,3]/3600)/df.iloc[x,5]*100
    # %error flue gas
    M[x,35] = abs(df.iloc[x,14] - (M[x,3] + M[x,17] - M[x,18])/3600)/df.iloc[x,14]*100
    # GT efficiency
    M[x,36] = M[x,1]/(M[x,0]/df.iloc[x,19])*100
    # Net efficiency
    M[x,37] = M[x,33]/(df.iloc[x,25]/ 348631 * 141000 * 26.21/3600)*100



# order of output matrix M
# (1)Net power of balance-of-the-plant  (2)power of GT/comporessor  (3)GT gross power  (4)gas flow to SOFC  (5)composition to SOFC: H2O
# (6)O2  (7)N2 (8)CO (9)CO2 (10)H2 (11)CH4 (12)Area of HX1  (13)Area of HXpreh  (14)HX1 Temp Hotin  (15)Hotout  (16)Coldin  (17)Coldout 
# (18)Airflow total  (19)Air bypass (20)gas flow from postcombustor  (21)Temp to GT before mixing  (22)Temp to GT after mixing  
# (23)HX1 heat duty  (24)HXpreh heat duty  (25)GT isentropic efficiency  (26)pinch point  (27)net power  (28)%error fuel (29)%error flue 

Op = pd.DataFrame(M)
Op.to_csv(path_or_buf='SimuOutputsPart2_bc4.csv',sep=',',header=None,index=None)
