import pandas as pd
import numpy as np
import matplotlib   
import matplotlib.pyplot as plt
from matplotlib.ticker import (MultipleLocator, FormatStrFormatter,
                               AutoMinorLocator)

# Graphing for Case 4

inlets = pd.read_csv('ModifiedData_bc4.csv', header=None)
inl = pd.DataFrame(inlets)

outlets1 = pd.read_csv('SimuOutputsPart1_bc4.csv', header=None)
outl1 = pd.DataFrame(outlets1)

outlets = pd.read_csv('SimuOutputsPart2_bc4.csv', header=None)
outl = pd.DataFrame(outlets)

sofcprofile = pd.read_csv('datarecord_bc4.csv', header=None)
sofc = pd.DataFrame(sofcprofile)

stack = 1
Acs = 400
s = 19  #  # of cases in Part1
n = 0   #  lifetime of SOFC (FU=0.25)

while inl.iloc[n,3] > 0.25:
        n = n + 1

print(n)
print(inl.iloc[n,3])

matplotlib.rc('xtick', labelsize=14)     
matplotlib.rc('ytick', labelsize=14)
font = {'family' : 'Times New Roman',
        'size'   : 16}	
matplotlib.rc('font', **font)
plt.rcParams["font.family"] = "serif"
plt.rcParams["font.serif"] = ["Times New Roman"] + plt.rcParams["font.serif"]

# power 
ntpr = pd.concat([outl1.iloc[0:s,33], outl.iloc[s:n,33]])
gtpr = pd.concat([outl1.iloc[0:s,1], outl.iloc[s:n,1]])
stpr = pd.concat([outl1.iloc[0:s,27], outl.iloc[s:n,27]]) - pd.concat([outl1.iloc[0:s,28], outl.iloc[s:n,28]])


scalefactor = 550/(sum(ntpr)/len(ntpr))
stack = stack*scalefactor

# fig, ax = plt.subplots()
# ax.plot(list(range(1,n+1)),outl1.iloc[:n,33], 'r-', label='Net Power1')
# ax.plot(list(range(1,n+1)),ntpr, 'k--', label='Net Power2')
# ax.plot(list(range(1,n+1)),-outl1.iloc[:n,1], 'r--', label='GT Power1')
# ax.plot(list(range(1,n+1)),-gtpr, 'k:', label='GT Power2')
# ax.plot(list(range(1,n+1)),-(outl1.iloc[:n,27]-outl1.iloc[:n,28]), 'r:', label='ST Power1')
# ax.plot(list(range(1,n+1)),-stpr, 'k-', label='ST Power2')
# plt.xlabel('Week')
# plt.ylabel('Power [MW]')
# plt.xlim(1,380)
# leg = ax.legend()
# chartBox = ax.get_position()
# ax.set_position([chartBox.x0*1.5, chartBox.y0*2.3, chartBox.width*0.9, chartBox.height*0.9])
# ax.legend(loc='upper center', bbox_to_anchor=(0.5, -0.15), ncol=3)
# plt.savefig('Power_bc4.tif',dpi=200)

# fig, ax = plt.subplots()
# ax.plot(list(range(1,n+1)),-outl1.iloc[:n,1], 'r--', label='GT Power1')
# ax.plot(list(range(1,n+1)),-gtpr, 'k:', label='GT Power2')
# plt.xlabel('Week')
# plt.ylabel('Power [MW]')
# plt.xlim(1,380)
# leg = ax.legend()
# chartBox = ax.get_position()
# ax.set_position([chartBox.x0*1.5, chartBox.y0*2.3, chartBox.width*0.9, chartBox.height*0.9])
# ax.legend(loc='upper center', bbox_to_anchor=(0.5, -0.15), ncol=2)
# plt.savefig('GTPower_bc4.tif',dpi=200)

# fig, ax = plt.subplots()
# ax.plot(list(range(1,n+1)),-(outl1.iloc[:n,27]-outl1.iloc[:n,28]), 'r:', label='ST Power1')
# ax.plot(list(range(1,n+1)),-stpr, 'k-', label='ST Power2')
# plt.xlabel('Week')
# plt.ylabel('Power [MW]')
# plt.xlim(1,380)
# leg = ax.legend()
# chartBox = ax.get_position()
# ax.set_position([chartBox.x0*1.5, chartBox.y0*2.3, chartBox.width*0.9, chartBox.height*0.9])
# ax.legend(loc='upper center', bbox_to_anchor=(0.5, -0.15), ncol=2)
# plt.savefig('STPower_bc4.tif',dpi=200)

fig, ax = plt.subplots()
ax.plot(list(range(1,n+1)),inl.iloc[:n,20]*scalefactor, 'r-', label='Stack Power')
ax.plot(list(range(1,n+1)),-gtpr*scalefactor, 'k--', label='GT Power')
ax.plot(list(range(1,n+1)),ntpr*scalefactor, 'k-', label='Net Power')
ax.plot(list(range(1,n+1)),-stpr*scalefactor, 'r:', label='Steam cycle Power')
plt.xlabel('Week')
plt.ylabel('Power [MW]')
plt.xlim(1,380)
leg = ax.legend()
chartBox = ax.get_position()
ax.set_position([chartBox.x0*1.5, chartBox.y0*2.6, chartBox.width*0.85, chartBox.height*0.85])
ax.legend(loc='upper center', bbox_to_anchor=(0.5, -0.15), ncol=2)
plt.savefig('Power_bc4.tif',dpi=200, figsize=[8,6])

fig, ax = plt.subplots()
ax.plot(list(range(1,n+1)),-stpr*scalefactor, 'r:', label='Steam cycle Power')
plt.xlabel('Week')
plt.ylabel('Power [MW]')
plt.xlim(1,380)
leg = ax.legend()
chartBox = ax.get_position()
ax.set_position([chartBox.x0*1.5, chartBox.y0*2.6, chartBox.width*0.85, chartBox.height*0.85])
ax.legend(loc='upper center', bbox_to_anchor=(0.5, -0.15), ncol=1)
plt.savefig('STPower_bc4.tif',dpi=200)

# efficiency
# gtef = outl.iloc[:,1]/(outl.iloc[:,0]/inl.iloc[:,19])*100
# ntef = outl.iloc[:,26]/(inl.iloc[:,25]/ 348631 * 141000 * 26.21/3600)*100

gtef = pd.concat([outl1.iloc[0:s,36], outl.iloc[s:n,36]])
ntef = pd.concat([outl1.iloc[0:s,37], outl.iloc[s:n,37]])
stef = -pd.concat([outl1.iloc[0:s,27], outl.iloc[s:n,27]])/pd.concat([outl1.iloc[0:s,30], outl.iloc[s:n,30]])*100

# fig, ax = plt.subplots()
# ax.plot(list(range(1,n+1)),outl1.iloc[:n,37], 'r-', label='Net Eff1')
# ax.plot(list(range(1,n+1)),ntef, 'k--', label='Net Eff2')
# ax.plot(list(range(1,n+1)),outl1.iloc[:n,36], 'r--', label='GT Eff1')
# ax.plot(list(range(1,n+1)),gtef, 'k-', label='GT Eff2')

# plt.xlabel('Week')
# plt.ylabel('Efficiency [%]')
# plt.xlim(1,380)
# leg = ax.legend()
# chartBox = ax.get_position()
# ax.set_position([chartBox.x0*1.5, chartBox.y0*2.3, chartBox.width*0.9, chartBox.height*0.9])
# ax.legend(loc='upper center', bbox_to_anchor=(0.5, -0.15), ncol=2)
# plt.savefig('Effic_bc4.tif',dpi=200)

fig, ax = plt.subplots()
ax.plot(list(range(1,n+1)),inl.iloc[:n,23]*100, 'r-', label='Stack Eff')
ax.plot(list(range(1,n+1)),gtef, 'k--', label='GT Eff')
ax.plot(list(range(1,n+1)),ntef, 'k-', label='Net Eff')
ax.plot(list(range(1,n+1)),stef, 'r:', label='Steam cycle Eff')
plt.xlabel('Week')
plt.ylabel('Efficiency [%]')
plt.xlim(1,380)
leg = ax.legend()
chartBox = ax.get_position()
ax.set_position([chartBox.x0*1.5, chartBox.y0*2.6, chartBox.width*0.85, chartBox.height*0.85])
ax.legend(loc='upper center', bbox_to_anchor=(0.5, -0.15), ncol=2)
plt.savefig('Effic_bc4.tif',dpi=200)


# # power and efficiency
fig, ax1 = plt.subplots()
ax1.plot(list(range(1,n+1)),inl.iloc[:n,20]*scalefactor, 'r-', label='Stack Power')
ax1.plot(list(range(1,n+1)),-gtpr*scalefactor, 'r:', label='GT Power')
ax1.plot(list(range(1,n+1)),ntpr*scalefactor, 'k-', label='Net Power')
ax1.plot(list(range(1,n+1)),-stpr*scalefactor, 'k:', label='ST Power')
plt.xlabel('Week')
plt.ylabel('Power [MW]')
plt.xlim(1,380)
plt.grid(b=None, which='major', axis='both',color = 'lightgrey')

ax2 = ax1.twinx()
ax2.set_ylabel('Efficiency [%]')
ax2.plot(list(range(1,n+1)),inl.iloc[:n,23]*100, 'r--', label='Stack Efficiency')
ax2.plot(list(range(1,n+1)),gtef, 'r-.', label='GT Efficiency')
ax2.plot(list(range(1,n+1)),ntef, 'k--', label='Net Efficiency')
ax2.plot(list(range(1,n+1)),stef, 'k-.', label='ST Efficiency')
ax2.tick_params(axis='y')
plt.ylim(0,)

leg = ax.legend()
leg = ax2.legend()
chartBox = ax2.get_position()
ax2.set_position([chartBox.x0*1.5, chartBox.y0*2.6, chartBox.width*0.85, chartBox.height*0.85])
ax1.legend(loc='upper center', bbox_to_anchor=(0.5, -0.15), ncol=4)
ax2.legend(loc='upper center', bbox_to_anchor=(0.5, -0.28), ncol=4)
plt.savefig('2_Overall_bc4.tif',dpi=200, figsize=[16,14])


# SOFC profile
fig, ax1 = plt.subplots()
ax1.plot(range(20,sofc.shape[0]),sofc.iloc[20:,1]*stack, 'r-', label='Stack Power')
ax1.plot(range(20,sofc.shape[0]),sofc.iloc[20:,5]*stack, 'k-', label='Fuel Flow')
plt.xlabel('Time [h]')
plt.ylabel('Power [MW] / Fuel Flow [kg/s]')
plt.grid(b=None, which='major', axis='both',color = 'lightgrey')

ax2 = ax1.twinx()
ax2.set_ylabel(r'Voltage [V] / FU / Current Density [A/$\mathdefault{cm^2}$]')
ax2.plot(range(20,sofc.shape[0]),sofc.iloc[20:,2], 'r--', label='Voltage')
ax2.plot(range(20,sofc.shape[0]),sofc.iloc[20:,3], 'k--', label='FU')
ax2.plot(range(20,sofc.shape[0]),sofc.iloc[20:,15]/Acs, 'k-.', label='Current Density')
ax2.tick_params(axis='y')

leg = ax.legend()
leg = ax2.legend()
chartBox = ax2.get_position()
ax2.set_position([chartBox.x0*1.5, chartBox.y0*2.6, chartBox.width*0.85, chartBox.height*0.85])
ax1.legend(loc='upper center', bbox_to_anchor=(0.5, -0.15), ncol=2)
ax2.legend(loc='upper center', bbox_to_anchor=(0.5, -0.28), ncol=3)
plt.savefig('1_SOFCprofile_bc4.tif',dpi=200)

plt.show()

